@@ -134,9 +134,9 @@ RDO_PKG_MAP = [
               'designate', 'ec2-api', 'glance', 'heat', 'heat-templates',
               'ironic', 'ironic-discoverd', 'ironic-inspector',
               'ironic-python-agent', 'keystone', 'magnum', 'manila',
-              'mistral', 'monasca-agent', 'monasca-api', 'monasca-log-api',
-              'monasca-notification', 'monasca-persister',
-              'murano', 'neutron', 'neutron-fwaas',
+              'masakari', 'masakari-monitors', 'mistral', 'monasca-agent',
+              'monasca-api', 'monasca-log-api', 'monasca-notification',
+              'monasca-persister', 'murano', 'neutron', 'neutron-fwaas',
               'neutron-lbaas', 'neutron-vpnaas', 'nova', 'octavia', 'rally',
               'sahara', 'swift', 'Tempest', 'trove', 'tuskar',
               'vitrage', 'zaqar'],
@@ -155,7 +155,8 @@ SUSE_PKG_MAP = [
     MultiRule(
         # keep lists in alphabetic order
         mods=['ceilometer', 'cinder', 'designate', 'glance',
-              'heat', 'ironic', 'keystone', 'manila', 'mistral',
+              'heat', 'ironic', 'keystone', 'manila', 'masakari',
+              'masakari-monitors', 'mistral',
               'monasca-agent', 'monasca-api', 'monasca-log-api',
               'monasca-notification', 'monasca-persister',
               'neutron', 'nova', 'rally', 'sahara', 'swift',
@@ -168,7 +169,7 @@ SUSE_PKG_MAP = [
             'cue', 'designate', 'distil', 'drac', 'fuel', 'freezer', 'heat',
             'glance', 'glare', 'ironic', 'ironic-inspector-',
             'karbor', 'k8s', 'keystone',
-            'magnum', 'manila', 'mistral', 'monasca',
+            'magnum', 'manila', 'masakari', 'mistral', 'monasca',
             'murano', 'nimble', 'neutron', 'nova', 'oneview',
             'openstack', 'sahara', 'scci', 'searchlight',
             'senlin', 'smaug', 'solum', 'swift', 'tacker',
@@ -204,7 +205,7 @@ UBUNTU_PKG_MAP = [
             'barbican', 'ceilometer', 'cinder', 'cloudkitty', 'congress',
             'designate', 'fuel', 'heat', 'glance', 'ironic',
             'karbor',  'keystone',
-            'magnum', 'manila', 'mistral', 'monasca',
+            'magnum', 'manila', 'masakari', 'mistral', 'monasca',
             'murano', 'neutron', 'nova',
             'openstack', 'sahara',
             'senlin', 'swift',
